@@ -30,7 +30,7 @@ typedef struct FilterData
 } FilterData;
 
 static void
-dmap_db_default_init (DmapDbInterface * iface)
+dmap_db_default_init (G_GNUC_UNUSED DmapDbInterface * iface)
 {
 }
 
@@ -182,8 +182,7 @@ _apply_filter (guint id, DmapRecord * record, gpointer data)
 
 	fd = data;
 	if (fd->filter_def == NULL) {
-		g_hash_table_insert (fd->ht, GUINT_TO_POINTER (id),
-				     g_object_ref (record));
+		g_hash_table_insert (fd->ht, GUINT_TO_POINTER(id), g_object_ref (record));
 		goto done;
 	}
 
@@ -199,8 +198,7 @@ _apply_filter (guint id, DmapRecord * record, gpointer data)
 			query_value = def->value;
 
 			if (g_strcmp0 (query_key, "dmap.itemid") == 0) {
-				if (GPOINTER_TO_UINT (id) ==
-				    strtoul (query_value, NULL, 10)) {
+				if (id == strtoul (query_value, NULL, 10)) {
 					accept = TRUE;
 					break;
 				}
@@ -237,7 +235,7 @@ _apply_filter (guint id, DmapRecord * record, gpointer data)
 		}
 	}
 	if (accept) {
-		g_hash_table_insert (fd->ht, GUINT_TO_POINTER (id),
+		g_hash_table_insert (fd->ht, GUINT_TO_POINTER(id),
 				     g_object_ref (record));
 	}
 
