@@ -39,7 +39,7 @@ struct DmapGstMP3InputStreamPrivate
 };
 
 static void
-_pad_added_cb (GstElement * element,
+_pad_added_cb (G_GNUC_UNUSED GstElement * element,
                GstPad * pad,
                GstElement *convert)
 {
