@@ -18,13 +18,13 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef _GST_UTIL
-#define _GST_UTIL
+#ifndef _GST_UTIL_H
+#define _GST_UTIL_H
 
 #include <gst/gst.h>
 
-gboolean pads_compatible (GstPad * pad1, GstPad * pad2);
+gboolean gst_util_pads_compatible (GstPad * pad1, GstPad * pad2);
 
-#endif /* _GST_UTIL */
+#endif
 
 G_END_DECLS
