@@ -158,7 +158,7 @@ test_dmap_av_record_set_property (GObject *object,
 			if (record->priv->hash) {
 				g_array_unref(record->priv->hash);
 			}
-			record->priv->hash = g_value_get_boxed (value);
+			record->priv->hash = g_array_ref(g_value_get_boxed (value));
 			break;
                 default:
                         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -236,7 +236,7 @@ test_dmap_av_record_get_property (GObject *object,
                         g_value_set_enum (value, record->priv->mediakind);
 			break;
 		case PROP_HASH:
-			g_value_set_boxed (value, record->priv->hash);
+			g_value_set_boxed (value, g_array_ref(record->priv->hash));
 			break;
                 default:
                         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -274,6 +274,7 @@ test_dmap_av_record_init (TestDmapAvRecord *record)
 	record->priv = TEST_DMAP_AV_RECORD_GET_PRIVATE (record);
 }
 
+static void test_dmap_av_record_dispose  (GObject *object);
 static void test_dmap_av_record_finalize (GObject *object);
 
 static void
@@ -283,6 +284,7 @@ test_dmap_av_record_class_init (TestDmapAvRecordClass *klass)
 
 	gobject_class->set_property = test_dmap_av_record_set_property;
         gobject_class->get_property = test_dmap_av_record_get_property;
+        gobject_class->dispose      = test_dmap_av_record_dispose;
         gobject_class->finalize     = test_dmap_av_record_finalize;
 
         g_object_class_override_property (gobject_class, PROP_LOCATION, "location");
@@ -316,7 +318,7 @@ test_dmap_av_record_class_init (TestDmapAvRecordClass *klass)
 }
 
 static void
-_dmap_av_record_iface_init (gpointer iface, gpointer data)
+_dmap_av_record_iface_init (gpointer iface)
 {
 	DmapAvRecordInterface *dmap_av_record = iface;
 
@@ -327,7 +329,7 @@ _dmap_av_record_iface_init (gpointer iface, gpointer data)
 }
 
 static void
-_dmap_record_iface_init (gpointer iface, gpointer data)
+_dmap_record_iface_init (gpointer iface)
 {
 	DmapRecordInterface *dmap_record = iface;
 
@@ -339,6 +341,19 @@ G_DEFINE_TYPE_WITH_CODE (TestDmapAvRecord, test_dmap_av_record, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, _dmap_record_iface_init)
                          G_ADD_PRIVATE (TestDmapAvRecord))
 
+static void
+test_dmap_av_record_dispose (GObject *object)
+{
+	TestDmapAvRecord *record = TEST_DMAP_AV_RECORD (object);
+
+	if (record->priv->hash) {
+		g_array_unref(record->priv->hash);
+	}
+	record->priv->hash = NULL;
+
+	G_OBJECT_CLASS (test_dmap_av_record_parent_class)->dispose (object);
+}
+
 static void
 test_dmap_av_record_finalize (GObject *object)
 {
@@ -354,10 +369,6 @@ test_dmap_av_record_finalize (GObject *object)
 	g_free (record->priv->sort_artist);
 	g_free (record->priv->genre);
 
-	if (record->priv->hash) {
-		g_array_unref(record->priv->hash);
-	}
-
 	G_OBJECT_CLASS (test_dmap_av_record_parent_class)->finalize (object);
 }
 
@@ -374,19 +385,14 @@ TestDmapAvRecord *test_dmap_av_record_new (void)
 	g_free (dir);
 
 	record->priv->title = g_strdup ("Unknown");
-
 	record->priv->album = g_strdup ("Unknown");
-
+	record->priv->sort_album = g_strdup ("Unknown");
 	record->priv->artist = g_strdup ("Unknown");
-
+	record->priv->sort_artist = g_strdup ("Unknown");
 	record->priv->bitrate = 128;
-
 	record->priv->firstseen = 1;
-
 	record->priv->mtime = 1;
-
 	record->priv->disc = 1;
-
 	record->priv->genre = g_strdup ("Unknown");
 
 	ext = strrchr (record->priv->location, '.');
@@ -396,6 +402,7 @@ TestDmapAvRecord *test_dmap_av_record_new (void)
 		ext++;
 	}
 	record->priv->format = g_strdup (ext);
+	record->priv->real_format = g_strdup (ext);
 
 	record->priv->filesize = 33729;
 
