@@ -98,13 +98,13 @@ test_dmap_image_record_set_property (GObject *object,
 			if (record->priv->thumbnail) {
 				g_array_unref(record->priv->thumbnail);
 			}
-                        record->priv->thumbnail = g_value_get_boxed (value);
+                        record->priv->thumbnail = g_array_ref(g_value_get_boxed (value));
                         break;
                 case PROP_HASH:
 			if (record->priv->hash) {
 				g_array_unref(record->priv->hash);
 			}
-                        record->priv->hash = g_value_get_boxed (value);
+                        record->priv->hash = g_array_ref(g_value_get_boxed (value));
                         break;
                 case PROP_COMMENTS:
 			g_free (record->priv->comments);
@@ -154,10 +154,10 @@ test_dmap_image_record_get_property (GObject *object,
                         g_value_set_string (value, record->priv->format);
                         break;
                 case PROP_THUMBNAIL:
-			g_value_set_boxed (value, record->priv->thumbnail);
+			g_value_set_boxed (value, g_array_ref(record->priv->thumbnail));
                         break;
                 case PROP_HASH:
-			g_value_set_boxed (value, record->priv->hash);
+			g_value_set_boxed (value, g_array_ref(record->priv->hash));
                         break;
                 case PROP_COMMENTS:
                         g_value_set_string (value, record->priv->comments);
@@ -216,7 +216,7 @@ test_dmap_image_record_class_init (TestDmapImageRecordClass *klass)
 }
 
 static void
-_dmap_image_record_iface_init (gpointer iface, gpointer data)
+_dmap_image_record_iface_init (gpointer iface)
 {
 	DmapImageRecordInterface *dmap_image_record = iface;
 
@@ -226,7 +226,7 @@ _dmap_image_record_iface_init (gpointer iface, gpointer data)
 }
 
 static void
-_dmap_record_iface_init (gpointer iface, gpointer data)
+_dmap_record_iface_init (gpointer iface)
 {
         DmapRecordInterface *dmap_record = iface;
 
